<?php
defined('_JEXEC') or die;

use Joomla\CMS\MVC\Model\BaseDatabaseModel;
use Joomla\CMS\Factory;
use Joomla\CMS\Date\Date;

class ZonenationspayModelReports extends BaseDatabaseModel
{
    public function getTransactionSummary($startDate, $endDate)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true);

        $query->select('COUNT(*) as total_transactions')
              ->select('SUM(amount) as total_amount')
              ->select('AVG(amount) as average_amount')
              ->select('MIN(amount) as min_amount')
              ->select('MAX(amount) as max_amount')
              ->select('currency')
              ->from($db->quoteName('#__zonenationspay_transactions'))
              ->where($db->quoteName('transaction_date') . ' BETWEEN ' . $db->quote($startDate) . ' AND ' . $db->quote($endDate))
              ->group('currency');

        $db->setQuery($query);

        try {
            $results = $db->loadObjectList();
            return $results;
        } catch (Exception $e) {
            Factory::getApplication()->enqueueMessage($e->getMessage(), 'error');
            return false;
        }
    }

    public function getRevenueByGateway($startDate, $endDate)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true);

        $query->select('gateway')
              ->select('SUM(amount) as total_revenue')
              ->select('COUNT(*) as transaction_count')
              ->select('currency')
              ->from($db->quoteName('#__zonenationspay_transactions'))
              ->where($db->quoteName('transaction_date') . ' BETWEEN ' . $db->quote($startDate) . ' AND ' . $db->quote($endDate))
              ->group('gateway, currency')
              ->order('total_revenue DESC');

        $db->setQuery($query);

        try {
            $results = $db->loadObjectList();
            return $results;
        } catch (Exception $e) {
            Factory::getApplication()->enqueueMessage($e->getMessage(), 'error');
            return false;
        }
    }

    public function getUserGrowth($startDate, $endDate)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true);

        // Convert start and end dates to DateTime objects
        $start = new DateTime($startDate);
        $end = new DateTime($endDate);

        // Calculate the difference in days
        $interval = $start->diff($end);
        $daysDiff = $interval->days;

        // Determine the appropriate grouping based on the date range
        if ($daysDiff <= 30) {
            $grouping = 'DATE(registerDate)';
            $dateFormat = '%Y-%m-%d';
        } elseif ($daysDiff <= 365) {
            $grouping = 'YEARWEEK(registerDate)';
            $dateFormat = '%X-W%V';
        } else {
            $grouping = 'EXTRACT(YEAR_MONTH FROM registerDate)';
            $dateFormat = '%Y-%m';
        }

        $query->select('DATE_FORMAT(registerDate, ' . $db->quote($dateFormat) . ') as period')
              ->select('COUNT(*) as new_users')
              ->from($db->quoteName('#__users'))
              ->where($db->quoteName('registerDate') . ' BETWEEN ' . $db->quote($startDate) . ' AND ' . $db->quote($endDate))
              ->group($grouping)
              ->order('registerDate ASC');

        $db->setQuery($query);

        try {
            $results = $db->loadObjectList();

            // Calculate cumulative growth
            $cumulativeGrowth = 0;
            foreach ($results as &$row) {
                $cumulativeGrowth += $row->new_users;
                $row->cumulative_users = $cumulativeGrowth;
            }

            return $results;
        } catch (Exception $e) {
            Factory::getApplication()->enqueueMessage($e->getMessage(), 'error');
            return false;
        }
    }

    public function getTopSpenders($startDate, $endDate, $limit = 10)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true);

        $query->select('u.id, u.name, u.username')
              ->select('SUM(t.amount) as total_spent')
              ->select('COUNT(t.id) as transaction_count')
              ->from($db->quoteName('#__zonenationspay_transactions', 't'))
              ->join('INNER', $db->quoteName('#__users', 'u') . ' ON t.user_id = u.id')
              ->where($db->quoteName('t.transaction_date') . ' BETWEEN ' . $db->quote($startDate) . ' AND ' . $db->quote($endDate))
              ->group('u.id')
              ->order('total_spent DESC')
              ->setLimit($limit);

        $db->setQuery($query);

        try {
            $results = $db->loadObjectList();
            return $results;
        } catch (Exception $e) {
            Factory::getApplication()->enqueueMessage($e->getMessage(), 'error');
            return false;
        }
    }

    public function getTransactionsByType($startDate, $endDate)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true);

        $query->select('transaction_type')
              ->select('COUNT(*) as transaction_count')
              ->select('SUM(amount) as total_amount')
              ->select('currency')
              ->from($db->quoteName('#__zonenationspay_transactions'))
              ->where($db->quoteName('transaction_date') . ' BETWEEN ' . $db->quote($startDate) . ' AND ' . $db->quote($endDate))
              ->group('transaction_type, currency')
              ->order('total_amount DESC');

        $db->setQuery($query);

        try {
            $results = $db->loadObjectList();
            return $results;
        } catch (Exception $e) {
            Factory::getApplication()->enqueueMessage($e->getMessage(), 'error');
            return false;
        }
    }
}

