<?php
/*
 * @component ZoneNationsPay
 * @copyright Copyright (C) 2023 Druskus ZoneNations https://zonenations.com
 * @license GNU/GPL v2 http://www.gnu.org/licenses/gpl-2.0.html
 */
defined('_JEXEC') or die();

use Joomla\CMS\MVC\Model\ListModel;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Date\Date;
use Joomla\Database\ParameterType;

class ZoneNationsPayModelZoneNationsPay extends ListModel
{
    public $_moneySettingsData;
    public $filename = "zonenationspay.php";
    public $view = "zonenationspay";

    public function __construct($config = array())
    {
        parent::__construct($config);
        $this->getMoneySettings();
    }

    public function getParams()
    {
        return ComponentHelper::getParams('com_zonenationspay');
    }

    public function checkParams()
    {
        $params = $this->getParams();

        $transactionfee     = $params->get('transactionfee');
        $paypaltype         = $params->get('sandboxmode');
        $currencyratebuy    = $params->get('currencyratebuy');
        $currencyratesell   = $params->get('currencyratesell');
        $userlimit_day      = $params->get('userlimit_day');
        $userlimit_week     = $params->get('userlimit_week');
        $userlimit_month    = $params->get('userlimit_month');

        $notifytransaction  = $params->get('notifytransaction');
        $notifyerror        = $params->get('notifyerror');
        $notifywarning      = $params->get('notifywarning');
        $notifyemail        = $params->get('notifyemail');
        $log2file           = $params->get('log2file');

        $logpath            = $params->get('logpath');

        $paypalaccount = $paypaltype ? $params->get('paypal_sandbox') : $params->get('paypal_account');

        if($this->checkVar($paypalaccount, "email") === FALSE) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_ZONENATIONSPAY_ERROR_PAYPALACCOUNT_INVALID'), 'warning');
        }

        if(!$currencyratebuy) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_ZONENATIONSPAY_ERROR_XCHANGEBUY_MISSING'), 'warning');
        } elseif($this->checkVar($currencyratebuy, "number") === FALSE) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_ZONENATIONSPAY_ERROR_XCHANGEBUY_INVALID'), 'warning');
        }

        // ... (other parameter checks remain the same, just update the component name in the language strings)

        if($log2file > 0 && !$logpath) {
            $recommendpath = dirname($_SERVER["DOCUMENT_ROOT"]."../")."/znlogs/";
            Factory::getApplication()->enqueueMessage(Text::sprintf('COM_ZONENATIONSPAY_ERROR_NOLOGPATH', $recommendpath), 'warning');
        } elseif($log2file > 0 && !is_dir($logpath)) {
            Factory::getApplication()->enqueueMessage(Text::sprintf('COM_ZONENATIONSPAY_ERROR_INVALIDLOGPATH', $logpath), 'warning');
        } elseif($log2file > 0 && !is_writable($logpath)) {
            Factory::getApplication()->enqueueMessage(Text::sprintf('COM_ZONENATIONSPAY_ERROR_NOWRITELOGPATH', $logpath), 'warning');
        }
    }

    public function getMoneySettings()
    {
        if (empty($this->_moneySettingsData)) {
            $settings = array();
            $params = ComponentHelper::getParams('com_opensim');

            $settings['name']               = $params->get('zonenationsmoney_currencyname');
            $settings['bankerUID']          = $params->get('zonenationsmoneybanker');
            $settings['groupCharge']        = $params->get('zonenationsmoney_groupcreation');
            $settings['uploadCharge']       = $params->get('zonenationsmoney_upload');
            $settings['groupMinDividend']   = $params->get('zonenationsmoney_groupdividend');
            $settings['startBalance']       = $params->get('zonenationsmoney_startbalance');

            $this->_moneySettingsData = $settings;
        }
        return $this->_moneySettingsData;
    }

    public function checkVar($var, $type)
    {
        return match($type) {
            "email" => filter_var($var, FILTER_VALIDATE_EMAIL) !== false,
            "number" => is_numeric($var),
            default => false,
        };
    }

    public function transactionpaypal($joomlaid)
    {
        $db = Factory::getDbo();
        $query = $db->getQuery(true)
            ->select('DISTINCT(#__zonenationspay_transactions.payer_email)')
            ->from('#__zonenationspay_transactions')
            ->order('#__zonenationspay_transactions.payer_email')
            ->where('#__zonenationspay_transactions.joomlaid = :joomlaid')
            ->bind(':joomlaid', $joomlaid, ParameterType::INTEGER);
        
        return $db->setQuery($query)->loadColumn();
    }

    public function getOpenSimNames($items)
    {
        if(!is_array($items)) return FALSE;
        foreach($items as $key => $item) {
            $items[$key]->opensimname = $this->getOpenSimName($item->opensimid);
        }
        return $items;
    }

    public function getOpenSimName($uuid)
    {
        $opensim = $this->opensimclass();
        $name = $opensim->getUserName($uuid, 'full');
        return $name;
    }

    public function getOpenSimData($uuid)
    {
        $opensim = $this->opensimclass();
        $data = $opensim->getUserData($uuid);
        return $data;
    }

    public function opensimclass()
    {
        $params = ComponentHelper::getParams('com_opensim');

        $osdbhost       = $params->get('opensim_dbhost');
        $osdbuser       = $params->get('opensim_dbuser');
        $osdbpasswd     = $params->get('opensim_dbpasswd');
        $osdbname       = $params->get('opensim_dbname');
        $osdbport       = $params->get('opensim_dbport');
        $osgriddbhost   = $params->get('opensimgrid_dbhost');
        $osgriddbuser   = $params->get('opensimgrid_dbuser');
        $osgriddbpasswd = $params->get('opensimgrid_dbpasswd');
        $osgriddbname   = $params->get('opensimgrid_dbname');
        $osgriddbport   = $params->get('opensimgrid_dbport');
        $opensim = new opensim($osgriddbhost, $osgriddbuser, $osgriddbpasswd, $osgriddbname, $osgriddbport);
        return $opensim;
    }

    public function newTransactions($sincedate)
    {
        $date = Factory::getDate($sincedate);
        $db = Factory::getDbo();
        $query = $db->getQuery(true)
            ->select('COUNT(*)')
            ->from('#__zonenationspay_transactions')
            ->where('transactiontime > :sincedate')
            ->bind(':sincedate', $date->toSql());
        
        return $db->setQuery($query)->loadResult();
    }

    public function newPayouts($sincedate)
    {
        $date = Factory::getDate($sincedate);
        $db = Factory::getDbo();
        $query = $db->getQuery(true)
            ->select('COUNT(*)')
            ->from('#__zonenationspay_payoutrequests')
            ->where('requesttime > :sincedate')
            ->bind(':sincedate', $date->toSql());
        
        return $db->setQuery($query)->loadResult();
    }

    public function unsolvedPayouts()
    {
        $db = Factory::getDbo();
        $query = $db->getQuery(true)
            ->select('COUNT(id) AS anzahl')
            ->select('status AS filter')
            ->select('ELT(status+2, "COM_ZONENATIONSPAY_PAYOUTSTATUS_PENDING", "COM_ZONENATIONSPAY_PAYOUTSTATUS_NEW", "COM_ZONENATIONSPAY_PAYOUTSTATUS_APPROVED") AS payoutstatus')
            ->from('#__zonenationspay_payoutrequests')
            ->where('FIND_IN_SET(status, "-1,0,1")')
            ->group('status');
        
        return $db->setQuery($query)->loadObjectList();
    }

    public function changePayout()
    {
        $app = Factory::getApplication();
        $payoutid = $app->input->getInt('payoutid');
        $newstatus = $app->input->getInt('newstatus');
        $remarks = $app->input->getString('remarks');

        $object = new \stdClass();
        $object->id = $payoutid;
        $object->status = $newstatus;
        $object->remarks = $remarks;
        $object->lastchange = (new Date())->toSql();

        $db = Factory::getDbo();

        if ($newstatus == 2) {
            $query = $db->getQuery(true)
                ->select(['opensimid', 'amount_iwc', 'transferred'])
                ->from('#__zonenationspay_payoutrequests')
                ->where('id = :payoutid')
                ->bind(':payoutid', $payoutid, ParameterType::INTEGER);
            
            $result = $db->setQuery($query)->loadObject();
            
            if ($result && $result->transferred == 0) {
                $banker = $this->_moneySettingsData['bankerUID'];
                $parameter = [
                    'senderID' => $result->opensimid,
                    'receiverID' => $banker,
                    'amount' => $result->amount_iwc,
                    'description' => Text::_('COM_ZONENATIONSPAY_PAYOUT_TRANSACTIONTEXT')
                ];
                
                $transferresult = TransferMoney($parameter);
                if (!is_array($transferresult) || !isset($transferresult['success']) || $transferresult['success'] !== true) {
                    return [
                        'type' => "error",
                        'message' => Text::_('COM_ZONENATIONSPAY_PAYOUTCHANGE_ERROR')
                    ];
                }
                $object->transferred = 1;
            }
        }

        try {
            $result = $db->updateObject('#__zonenationspay_payoutrequests', $object, 'id');
            return [
                'type' => "message",
                'message' => Text::_('COM_ZONENATIONSPAY_PAYOUTCHANGE_OK')
            ];
        } catch (Exception $e) {
            return [
                'type' => "error",
                'message' => Text::_('COM_ZONENATIONSPAY_PAYOUTCHANGE_ERROR')
            ];
        }
    }

    // New methods for Region Rent

    public function getRegionRents()
    {
        $db = Factory::getDbo();
        $query = $db->getQuery(true)
            ->select('*')
            ->from($db->quoteName('#__zonenationspay_regions'));
        
        $db->setQuery($query);
        return $db->loadObjectList();
    }

    public function addRegionRent($regionName, $rentalPrice)
    {
        $db = Factory::getDbo();
        $object = new \stdClass();
        $object->region_name = $regionName;
        $object->rental_price = $rentalPrice;

        try {
            $result = $db->insertObject('#__zonenationspay_regions', $object);
            return [
                'success' => true,
                'message' => Text::_('COM_ZONENATIONSPAY_REGION_RENT_ADDED')
            ];
        } catch (Exception $e) {
            return [
                'success' => false,
                'message' => Text::_('COM_ZONENATIONSPAY_REGION_RENT_ADD_ERROR')
            ];
        }
    }

    public function updateRegionRent($id, $regionName, $rentalPrice)
    {
        $db = Factory::getDbo();
        $object = new \stdClass();
        $object->id = $id;
        $object->region_name = $regionName;
        $object->rental_price = $rentalPrice;

        try {
            $result = $db->updateObject('#__zonenationspay_regions', $object, 'id');
            return [
                'success' => true,
                'message' => Text::_('COM_ZONENATIONSPAY_REGION_RENT_UPDATED')
            ];
        } catch (Exception $e) {
            return [
                'success' => false,
                'message' => Text::_('COM_ZONENATIONSPAY_REGION_RENT_UPDATE_ERROR')
            ];
        }
    }

    public function deleteRegionRent($id)
    {
        $db = Factory::getDbo();
        $query = $db->getQuery(true)
            ->delete($db->quoteName('#__zonenationspay_regions'))
            ->where($db->quoteName('id') . ' = :id')
            ->bind(':id', $id, ParameterType::INTEGER);

        try {
            $db->setQuery($query)->execute();
            return [
                'success' => true,
                'message' => Text::_('COM_ZONENATIONSPAY_REGION_RENT_DELETED')
            ];
        } catch (Exception $e) {
            return [
                'success' => false,
                'message' => Text::_('COM_ZONENATIONSPAY_REGION_RENT_DELETE_ERROR')
            ];
        }
    }

    public function getRegionRent($id)
    {
        $db = Factory::getDbo();
        $query = $db->getQuery(true)
            ->select('*')
            ->from($db->quoteName('#__zonenationspay_regions'))
            ->where($db->quoteName('id') . ' = :id')
            ->bind(':id', $id, ParameterType::INTEGER);
        
        $db->setQuery($query);
        return $db->loadObject();
    }
}