<?php
/**
 * @component ZoneNationsPay
 * @copyright Copyright (C) 2023 Druskus ZoneNations https://www.zonenations.com
 * @license GNU/GPL v2 http://www.gnu.org/licenses/gpl-2.0.html
 */

// No direct access
defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\MVC\Controller\BaseController;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Component\ComponentHelper;

/**
 * ZoneNationsPay Component Controller
 */
class ZoneNationsPayController extends BaseController
{
    protected $model;
    public $opensim;

    /**
     * Constructor.
     *
     * @param   array  $config  An optional associative array of configuration settings.
     */
    public function __construct($config = array())
    {
        parent::__construct($config);

        if (!defined('COM_ZONENATIONSPAY_INWORLD_CURRENCYNAME')) {
            $model = $this->getModel('zonenationspay');
            $money = $model->getMoneySettings();
            $params = ComponentHelper::getParams('com_zonenationspay');
            $sandboxmode = $params->get('sandboxmode', 0);
            $noadd = Factory::getApplication()->input->getInt('noadd', 0);

            if ($sandboxmode && $noadd == 0) {
                Factory::getApplication()->enqueueMessage(Text::_('COM_ZONENATIONSPAY_SANDBOXMODE'), 'warning');
            }

            if (!empty($money['name'])) {
                define('COM_ZONENATIONSPAY_INWORLD_CURRENCYNAME', $money['name']);
            }
        }
    }

    /**
     * Method to remove a payout request
     */
    public function removerequest()
    {
        $model = $this->getModel('transactionlist');
        $result = $model->revokePayOut();
        if ($result) {
            $message = Text::_('COM_ZONENATIONSPAY_PAYOUT_REVOKE_OK');
            $type = 'message';
        } else {
            $message = Text::_('COM_ZONENATIONSPAY_PAYOUT_REVOKE_ERROR');
            $type = 'error';
        }
        $itemid = Factory::getApplication()->input->getInt('Itemid');
        $redirect = "index.php?option=com_zonenationspay&view=transactionlist&noadd=1&Itemid=" . $itemid;
        $this->setRedirect($redirect, $message, $type);
    }

    /**
     * Method to handle region rent payments
     */
    public function payRegionRent()
    {
        $model = $this->getModel('regionrent');
        $result = $model->processRegionRentPayment();
        if ($result) {
            $message = Text::_('COM_ZONENATIONSPAY_REGIONRENT_PAYMENT_SUCCESS');
            $type = 'message';
        } else {
            $message = Text::_('COM_ZONENATIONSPAY_REGIONRENT_PAYMENT_ERROR');
            $type = 'error';
        }
        $itemid = Factory::getApplication()->input->getInt('Itemid');
        $redirect = "index.php?option=com_zonenationspay&view=regionrent&Itemid=" . $itemid;
        $this->setRedirect($redirect, $message, $type);
    }

    /**
     * Method to display the view
     *
     * @param   boolean  $cachable   If true, the view output will be cached
     * @param   array    $urlparams  An array of safe URL parameters and their variable types
     *
     * @return  BaseController  This object to support chaining.
     */
    public function display($cachable = false, $urlparams = [])
    {
        $view = $this->input->getCmd('view', 'dashboard');
        $this->input->set('view', $view);
        parent::display($cachable, $urlparams);
        return $this;
    }

    /**
     * Handle BTCPay IPN (Instant Payment Notification)
     */
    public function btcpayIPN()
    {
        $model = $this->getModel('btcpay');
        $model->handleIPN();
        jexit();
    }
}

