<?php
defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Uri\Uri;

class ZonenationspayHelperNotifications
{
    public static function sendEmail($to, $subject, $body, $isHTML = true, $cc = null, $bcc = null, $attachments = null)
    {
        $mailer = Factory::getMailer();
        $config = Factory::getConfig();
        $sender = [
            $config->get('mailfrom'),
            $config->get('fromname')
        ];

        $mailer->setSender($sender)
               ->addRecipient($to)
               ->setSubject($subject);

        if ($isHTML) {
            $mailer->isHTML(true);
            $mailer->Encoding = 'base64';
        }

        $mailer->setBody($body);

        // Add CC recipients
        if (!empty($cc)) {
            $mailer->addCc($cc);
        }

        // Add BCC recipients
        if (!empty($bcc)) {
            $mailer->addBcc($bcc);
        }

        // Add attachments
        if (!empty($attachments)) {
            foreach ($attachments as $attachment) {
                $mailer->addAttachment($attachment);
            }
        }

        try {
            $send = $mailer->Send();
            return $send === true;
        } catch (Exception $e) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_ZONENATIONSPAY_EMAIL_SEND_FAILED') . ': ' . $e->getMessage(), 'error');
            return false;
        }
    }

    public static function sendSMS($to, $message)
    {
        // This is a placeholder implementation. You'll need to replace this with actual SMS gateway integration.
        // Example using Twilio:
        
        // Require the Twilio autoload file (you'll need to install the Twilio PHP SDK)
        // require_once JPATH_LIBRARIES . '/twilio/autoload.php';
        
        // Your Twilio Account SID and Auth Token
        // $account_sid = 'your_account_sid';
        // $auth_token = 'your_auth_token';
        
        // Create a new Twilio client
        // $client = new Twilio\Rest\Client($account_sid, $auth_token);
        
        try {
            // Send the SMS
            // $result = $client->messages->create(
            //     $to, // The number you'd like to send the message to
            //     [
            //         'from' => 'your_twilio_number', // Your Twilio number
            //         'body' => $message
            //     ]
            // );
            
            // If we get here, the message was sent successfully
            return true;
        } catch (Exception $e) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_ZONENATIONSPAY_SMS_SEND_FAILED') . ': ' . $e->getMessage(), 'error');
            return false;
        }
    }

    public static function sendPushNotification($userId, $message, $title = '')
    {
        // This is a placeholder implementation. You'll need to replace this with actual push notification service integration.
        // Example using Firebase Cloud Messaging (FCM):
        
        // First, you'd need to store FCM tokens for each user in your database
        // Let's assume we have a method to retrieve that
        $fcmToken = self::getFCMTokenForUser($userId);
        
        if (!$fcmToken) {
            return false;
        }
        
        // Your FCM server key
        // $serverKey = 'your_fcm_server_key';
        
        $data = [
            'to' => $fcmToken,
            'notification' => [
                'title' => $title,
                'body' => $message,
                'icon' => 'icon',
                'click_action' => Uri::base()
            ]
        ];

        $headers = [
            'Authorization: key=' . $serverKey,
            'Content-Type: application/json'
        ];

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, 'https://fcm.googleapis.com/fcm/send');
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));

        $result = curl_exec($ch);

        if ($result === false) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_ZONENATIONSPAY_PUSH_NOTIFICATION_FAILED') . ': ' . curl_error($ch), 'error');
            curl_close($ch);
            return false;
        }

        curl_close($ch);
        return true;
    }

    private static function getFCMTokenForUser($userId)
    {
        // This method should retrieve the FCM token for a given user from your database
        // This is just a placeholder implementation
        $db = Factory::getDbo();
        $query = $db->getQuery(true)
            ->select($db->quoteName('fcm_token'))
            ->from($db->quoteName('#__zonenationspay_user_tokens'))
            ->where($db->quoteName('user_id') . ' = ' . (int)$userId);
        $db->setQuery($query);
        return $db->loadResult();
    }
}

