<?php
#
#  Copyright (c)Melanie Thielker and Teravus Ovares (http://opensimulator.org/)
#
#  Redistribution and use in source and binary forms, with or without
#  modification, are permitted provided that the following conditions are met:
#      * Redistributions of source code must retain the above copyright
#        notice, this list of conditions and the following disclaimer.
#      * Redistributions in binary form must reproduce the above copyright
#        notice, this list of conditions and the following disclaimer in the
#        documentation and/or other materials provided with the distribution.
#      * Neither the name of the OpenSim Project nor the
#        names of its contributors may be used to endorse or promote products
#        derived from this software without specific prior written permission.
#
#  THIS SOFTWARE IS PROVIDED BY THE DEVELOPERS ``AS IS'' AND ANY
#  EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
#  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
#  DISCLAIMED. IN NO EVENT SHALL THE CONTRIBUTORS BE LIABLE FOR ANY
#  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
#  (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
#  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
#  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
#  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
//////////////////////////////////////////////////////////////////////////////
//
// Modified by Fumi.Iseki for CMS/LMS '09 5/31
// Modified by Adil El Farissi for the BTCPay integration.
//

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Component\ComponentHelper;

require_once JPATH_SITE . '/components/com_zonenationspay/helpers/btcpayhelper.php';

$params = ComponentHelper::getParams('com_zonenationspay');
$btcpayHelper = new ZoneNationsPayHelperBtcpay();

###################### No user serviceable parts below #####################
#
# The XMLRPC server object
#
$xmlrpc_server = xmlrpc_server_create();

#
# Land purchase sections
#
# Functions are called by the viewer directly.
#

#
# Land buying functions
#
xmlrpc_server_register_method($xmlrpc_server, "preflightBuyLandPrep", "buy_land_prep");

function buy_land_prep($method_name, $params, $app_data)
{
    global $btcpayHelper;
    $req          = $params[0];
    $agentid      = $req['agentId'];
    $secureid     = $req['secureSessionId'];
    $amount       = $req['currencyBuy'];
    $billableArea = $req['billableArea'];
    $ipAddress    = $_SERVER['REMOTE_ADDR'];

    $ret = $btcpayHelper->checkSecureSession($agentid, null, $secureid);
    if ($ret) {        
        $confirmvalue = $btcpayHelper->getConfirmValue($ipAddress);
        $membership_levels = array('levels' => array('id' => "00000000-0000-0000-0000-000000000000", 'description' => "some level"));
        $landUse    = array('upgrade' => False, 'action' => JURI::root());
        
        $cost = $btcpayHelper->convertToReal($amount, false);
        if ($cost != null) {
            $currency = array('estimatedLocalCost'=> $cost['fiatAmount'] . " " . $btcpayHelper->params->get('btcpay_fiat') . "  ~  " . $cost['cryptoAmount'] . " " . $btcpayHelper->params->get('btcpay_payment_cryptocurrency'));
        } else {
            $currency = array('estimatedLocalCost' => bcmul($amount, $btcpayHelper->params->get('local_currency_price'), 2) . " " . $btcpayHelper->params->get('btcpay_fiat') . "  \n  Rates Unavailable");
        }
        
        $membership = array('upgrade' => False, 'action' => JURI::root(), 'levels' => $membership_levels);
        $response_xml = xmlrpc_encode(array(
            'success'    => True,
            'currency'   => $currency,
            'membership' => $membership,
            'landUse'    => $landUse,                
            'confirm'    => $confirmvalue
        ));
    } else {
        $response_xml = xmlrpc_encode(array(
            'success'       => False,
            'errorMessage'  => "Unable to Authenticate\n\nClick URL for more info.",
            'errorURI'      => JURI::root()
        ));
    }
    
    header("Content-type: text/xml");
    echo $response_xml;
    return "";
}

#
# Perform the buy (所持金が足りないとき)
#
xmlrpc_server_register_method($xmlrpc_server, "buyLandPrep", "buy_land");

function buy_land($method_name, $params, $app_data)
{
    global $btcpayHelper;
    $req          = $params[0];
    $agentid      = $req['agentId'];
    $secureid     = $req['secureSessionId'];
    $amount       = $req['currencyBuy'];
    $cost         = $req['estimatedLocalCost'];
    $billableArea = $req['billableArea'];
    $confirm      = $req['confirm'];
    $ipAddress    = $_SERVER['REMOTE_ADDR'];

    if ($confirm != $btcpayHelper->getConfirmValue($ipAddress)) {
        $response_xml = xmlrpc_encode(array(
            'success'     => False,
            'errorMessage'=> "\n\nMismatch Confirm Value!!",
            'errorURI'    => JURI::root()
        ));
        header("Content-type: text/xml");
        echo $response_xml;
        return "";
    }

    $ret = $btcpayHelper->checkSecureSession($agentid, null, $secureid);
    if ($ret) {            
        if ($amount <= $btcpayHelper->getBalance($agentid)) {
            $btcpayHelper->updateSimulatorBalance($agentid, -1, $secureid);
            $response_xml = xmlrpc_encode(array('success' => True));
        } else {
            $response_xml = xmlrpc_encode(array(
                'success'     => False,
                'errorMessage'=> "\n\nYou do not have sufficient funds for this purchase. Please click [BUY " . $btcpayHelper->params->get('local_currency_symbol') . "] in the top menu to reload your balance."
            ));
        }        
    } else {
        $response_xml = xmlrpc_encode(array(
            'success'       => False,
            'errorMessage'  => "\n\nUnable to Authenticate\n\nClick URL for more info.",
            'errorURI'      => JURI::root()
        ));
    }
    
    header("Content-type: text/xml");
    echo $response_xml;
    return "";
}

#
# Process XMLRPC request
#
if (!isset($HTTP_RAW_POST_DATA)) $HTTP_RAW_POST_DATA = file_get_contents('php://input');
$request_xml = $HTTP_RAW_POST_DATA;
//error_log("landtool.php: ".$request_xml);

xmlrpc_server_call_method($xmlrpc_server, $request_xml, '');
xmlrpc_server_destroy($xmlrpc_server);
