<?php
/**
 * @component ZoneNationsPay
 * @copyright Copyright (C) 2023 Druskus ZoneNations https://www.zonenations.com
 * @license GNU/GPL v2 http://www.gnu.org/licenses/gpl-2.0.html
 */
defined('_JEXEC') or die();

use Joomla\CMS\MVC\Model\BaseDatabaseModel;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\HTML\HTMLHelper;

require_once(JPATH_COMPONENT . '/models/zonenationspay.php');

class ZonenationspayModelTransactionlist extends ZonenationspayModelZoneNationsPay
{
    public $filename = "transactionlist.php";
    public $view = "transactionlist";

    public function __construct($config = array())
    {
        parent::__construct($config);
    }

    public function paypalList($joomlaid)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true)
            ->select('*')
            ->from($db->quoteName('#__zonenationspay_transactions'))
            ->where($db->quoteName('joomlaid') . ' = ' . (int)$joomlaid)
            ->order($db->quoteName('transactiontime') . ' DESC');
        
        return $db->setQuery($query)->loadObjectList();
    }

    public function payoutList($joomlaid)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true)
            ->select('a.*, CASE 
                WHEN a.status = -2 THEN ' . $db->quote(Text::_('COM_ZONENATIONSPAY_PAYOUTSTATUS_CANCELED')) . '
                WHEN a.status = -1 THEN ' . $db->quote(Text::_('COM_ZONENATIONSPAY_PAYOUTSTATUS_PENDING')) . '
                WHEN a.status = 0 THEN ' . $db->quote(Text::_('COM_ZONENATIONSPAY_PAYOUTSTATUS_NEW')) . '
                WHEN a.status = 1 THEN ' . $db->quote(Text::_('COM_ZONENATIONSPAY_PAYOUTSTATUS_APPROVED')) . '
                WHEN a.status = 2 THEN ' . $db->quote(Text::_('COM_ZONENATIONSPAY_PAYOUTSTATUS_FINISHED')) . '
                ELSE ' . $db->quote(Text::_('COM_ZONENATIONSPAY_PAYOUTSTATUS_UNKNOWN')) . '
            END AS payoutstatus')
            ->select('CASE 
                WHEN a.status = -2 THEN ' . $db->quote('canceled.png') . '
                WHEN a.status = -1 THEN ' . $db->quote('pending.png') . '
                WHEN a.status = 0 THEN ' . $db->quote('new.png') . '
                WHEN a.status = 1 THEN ' . $db->quote('approved.png') . '
                WHEN a.status = 2 THEN ' . $db->quote('finished.png') . '
                ELSE ' . $db->quote('unknown.png') . '
            END AS payoutsymbol')
            ->from($db->quoteName('#__zonenationspay_payoutrequests', 'a'))
            ->where($db->quoteName('joomlaid') . ' = ' . (int)$joomlaid)
            ->order($db->quoteName('requesttime') . ' DESC');
        
        return $db->setQuery($query)->loadObjectList();
    }

    public function addPayOutImage($payoutlist)
    {
        if (!is_array($payoutlist) || empty($payoutlist)) {
            return $payoutlist;
        }

        foreach ($payoutlist as $key => $payout) {
            $payoutlist[$key]->statusimage = HTMLHelper::_('image', 'com_zonenationspay/images/' . $payout->payoutsymbol, Text::_($payout->payoutstatus), ['title' => Text::_($payout->payoutstatus)]);
            
            $tooltip = ['text' => '', 'title' => ''];
            if ($payout->status < 0 && $payout->remarks) {
                $tooltip['text'] = nl2br($payout->remarks);
            }
            if ($payout->lastchange) {
                $tooltip['title'] = Text::sprintf('COM_ZONENATIONSPAY_PAYOUTSTATUS_LASTCHANGE', $payout->lastchange);
            }
            if ($tooltip['text'] || $tooltip['title']) {
                $payoutlist[$key]->statusimage = HTMLHelper::_('tooltip', $tooltip['text'], $tooltip['title'], '', $payoutlist[$key]->statusimage);
            }
        }

        return $payoutlist;
    }

    public function revokePayOut()
    {
        $app = Factory::getApplication();
        $payoutid = $app->input->getInt('id');
        $user = Factory::getUser();
        return $this->deletePayout($payoutid, $user->id);
    }

    protected function deletePayout($payoutid, $userid)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true)
            ->delete($db->quoteName('#__zonenationspay_payoutrequests'))
            ->where([
                $db->quoteName('id') . ' = ' . (int)$payoutid,
                $db->quoteName('joomlaid') . ' = ' . (int)$userid
            ]);
        try {
            return $db->setQuery($query)->execute();
        } catch (Exception $e) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_ZONENATIONSPAY_PAYOUT_REVOKE_ERROR'), 'error');
            return false;
        }
    }

    public function getRegionRentTransactions($joomlaid)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true)
            ->select('*')
            ->from($db->quoteName('#__zonenationspay_regionrent_transactions'))
            ->where($db->quoteName('joomlaid') . ' = ' . (int)$joomlaid)
            ->order($db->quoteName('transaction_date') . ' DESC');
        
        return $db->setQuery($query)->loadObjectList();
    }
}
