<?php
defined('_JEXEC') or die;

use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Factory;

HTMLHelper::_('jquery.framework');
HTMLHelper::_('bootstrap.tooltip');
HTMLHelper::_('behavior.formvalidator');
HTMLHelper::_('behavior.keepalive');
HTMLHelper::_('formbehavior.chosen', 'select');

$app = Factory::getApplication();
$user = Factory::getUser();
$input = $app->input;
$amount = $input->get('amount', '', 'float');
?>

<div class="zonenationspay-btcpay-withdrawal">
    <h1><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_TITLE'); ?></h1>

    <?php if ($this->isWithdrawalDisabled): ?>
        <div class="alert alert-warning">
            <span class="icon-warning"></span>
            <?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_DISABLED', $this->cryptoSymbol); ?>
        </div>
    <?php else: ?>
        <div class="btcpay-withdrawal-info alert alert-info">
            <h3><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_INFO_TITLE'); ?></h3>
            <p><?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_INFO_DESC', $this->cryptoSymbol, $this->localCurrencySymbol); ?></p>
            <ul>
                <li><?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_MIN_AMOUNT', $this->withdrawalMinimum, $this->localCurrencySymbol); ?></li>
                <li><?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_FEE', $this->withdrawalFee, $this->localCurrencySymbol); ?></li>
                <li><?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_EXCHANGE_RATE', $this->localCurrencySymbol, $this->cryptoSymbol, $this->localCurrencyWithdrawalPrice); ?></li>
            </ul>
        </div>

        <form action="<?php echo Route::_('index.php?option=com_zonenationspay&task=btcpay.requestWithdrawal'); ?>" method="post" id="btcpayWithdrawalForm" class="form-validate form-horizontal">
            <div class="control-group">
                <div class="control-label">
                    <?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_AMOUNT_LABEL', $this->localCurrencySymbol); ?>
                </div>
                <div class="controls">
                    <input type="number" name="amount" id="amount" value="<?php echo $amount; ?>" min="<?php echo $this->withdrawalMinimum; ?>" max="<?php echo $this->userBalance; ?>" required class="required" />
                </div>
            </div>
            
            <div class="control-group">
                <div class="control-label">
                    <?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_ADDRESS_LABEL', $this->cryptoSymbol); ?>
                </div>
                <div class="controls">
                    <input type="text" name="address" id="address" required class="required" />
                </div>
            </div>
            
            <div class="control-group">
                <div class="controls">
                    <button type="submit" class="btn btn-primary validate">
                        <?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_SUBMIT'); ?>
                    </button>
                </div>
            </div>
            
            <?php echo HTMLHelper::_('form.token'); ?>
        </form>

        <div id="withdrawal-estimate" class="alert alert-info" style="display: none;">
            <h4><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_ESTIMATE_TITLE'); ?></h4>
            <p><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_ESTIMATE_DESC'); ?></p>
            <ul>
                <li><?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_ESTIMATE_AMOUNT', '<span id="estimate-amount"></span>', $this->localCurrencySymbol); ?></li>
                <li><?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_ESTIMATE_FEE', '<span id="estimate-fee"></span>', $this->localCurrencySymbol); ?></li>
                <li><?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_ESTIMATE_TOTAL', '<span id="estimate-total"></span>', $this->localCurrencySymbol); ?></li>
                <li><?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_ESTIMATE_CRYPTO', '<span id="estimate-crypto"></span>', $this->cryptoSymbol); ?></li>
            </ul>
        </div>

        <div class="btcpay-withdrawal-faq">
            <h3><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_FAQ_TITLE'); ?></h3>
            <dl>
                <dt><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_FAQ_Q1'); ?></dt>
                <dd><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_FAQ_A1'); ?></dd>
                
                <dt><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_FAQ_Q2'); ?></dt>
                <dd><?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_FAQ_A2', $this->cryptoSymbol); ?></dd>
                
                <dt><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_FAQ_Q3'); ?></dt>
                <dd><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_WITHDRAWAL_FAQ_A3'); ?></dd>
            </dl>
        </div>
    <?php endif; ?>
</div>

<script type="text/javascript">
jQuery(document).ready(function($) {
    $('#amount').on('change', function() {
        var amount = parseFloat($(this).val());
        var fee = <?php echo $this->withdrawalFee; ?>;
        var exchangeRate = <?php echo $this->localCurrencyWithdrawalPrice; ?>;
        
        var total = amount - fee;
        var estimatedCrypto = (total / exchangeRate).toFixed(8);
        
        $('#estimate-amount').text(amount.toFixed(2));
        $('#estimate-fee').text(fee.toFixed(2));
        $('#estimate-total').text(total.toFixed(2));
        $('#estimate-crypto').text(estimatedCrypto);
        
        $('#withdrawal-estimate').show();
    });
});
</script>


