<?php
/**
 * @component ZoneNationsPay
 * @copyright Copyright (C) 2023 Druskus ZoneNations https://www.zonenations.com
 * @license GNU/GPL v2 http://www.gnu.org/licenses/gpl-2.0.html
 */

defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\Language\Text;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Router\Route;

HTMLHelper::_('behavior.core');
HTMLHelper::_('stylesheet', 'com_zonenationspay/zonenationspay.css', ['version' => 'auto', 'relative' => true]);
?>

<div class="zonenationspay-limit-week<?php echo $this->pageclass_sfx; ?>">
    <?php if ($this->params->get('show_page_heading')) : ?>
        <div class="page-header">
            <h1><?php echo $this->escape($this->params->get('page_heading')); ?></h1>
        </div>
    <?php endif; ?>

    <h2><?php echo Text::_('COM_ZONENATIONSPAY_BUY_IWC'); ?></h2>
    
    <div class="alert alert-warning">
        <?php echo Text::_('COM_ZONENATIONSPAY_ERROR_USERLIMIT_WEEK'); ?>
    </div>

    <?php if (isset($this->weekly_limit)) : ?>
        <p>
            <?php echo Text::sprintf('COM_ZONENATIONSPAY_WEEKLY_LIMIT_INFO', $this->weekly_limit, $this->currency); ?>
        </p>
    <?php endif; ?>

    <?php if ($this->params->get('show_return_link', 1)) : ?>
        <div class="btn-group">
            <a href="<?php echo $this->return_link; ?>" class="btn btn-secondary">
                <span class="icon-chevron-left" aria-hidden="true"></span>
                <?php echo Text::_('COM_ZONENATIONSPAY_RETURN_TO_PROFILE'); ?>
            </a>
        </div>
    <?php endif; ?>

    <?php if ($this->params->get('show_regionrent_info', 1) && !empty($this->regionrent_info)) : ?>
        <div class="zonenationspay-regionrent-info mt-4">
            <h3><?php echo Text::_('COM_ZONENATIONSPAY_REGIONRENT_INFO'); ?></h3>
            <table class="table table-striped">
                <thead>
                    <tr>
                        <th><?php echo Text::_('COM_ZONENATIONSPAY_REGIONRENT_NAME'); ?></th>
                        <th><?php echo Text::_('COM_ZONENATIONSPAY_REGIONRENT_NEXT_DUE'); ?></th>
                        <th><?php echo Text::_('COM_ZONENATIONSPAY_REGIONRENT_AMOUNT'); ?></th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($this->regionrent_info as $region) : ?>
                        <tr>
                            <td><?php echo $this->escape($region->name); ?></td>
                            <td><?php echo HTMLHelper::_('date', $region->next_due, Text::_('DATE_FORMAT_LC4')); ?></td>
                            <td><?php echo $region->amount . ' ' . $this->currency; ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    <?php endif; ?>

    <?php if ($this->params->get('show_contact_support', 1)) : ?>
        <div class="zonenationspay-contact-support mt-4">
            <p><?php echo Text::_('COM_ZONENATIONSPAY_CONTACT_SUPPORT_INFO'); ?></p>
            <a href="<?php echo Route::_('index.php?option=com_contact&view=contact&id=' . $this->params->get('support_contact_id')); ?>" class="btn btn-primary">
                <?php echo Text::_('COM_ZONENATIONSPAY_CONTACT_SUPPORT'); ?>
            </a>
        </div>
    <?php endif; ?>
</div>


